@@ -21,17 +21,11 @@
 
 #include "memory.h"
 
-#include <QStringList>
 
 #include <QGroupBox>
-#include <QLayout>
-#include <QPainter>
-#include <QPixmap>
 #include <QVBoxLayout>
 #include <QHBoxLayout>
-#include <QLinearGradient>
-#include <QTreeWidget>
-
+#include <QLabel>
 #include <kaboutdata.h>
 
 #include <sys/param.h>		/* for BSD */
@@ -94,7 +88,7 @@ KCMMemory::KCMMemory(QWidget *parent, const QVariantList &) :
 	timer = new QTimer(this);
 	timer->start(100);
 
-	connect(timer, SIGNAL(timeout()), this, SLOT(updateDatas()));
+	connect(timer, &QTimer::timeout, this, &KCMMemory::updateDatas);
 	
 	updateDatas();
 }
